"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .pagepublicapiresponse import PagePublicAPIResponse
from .pagination import Pagination
from dataclasses_json import Undefined, dataclass_json
from typing import List, Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PaginatedResultPagePublicAPIResponse:
    pagination: Pagination = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination') }})
    total_count: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('totalCount') }})
    result: Optional[List[PagePublicAPIResponse]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('result'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from typing import Dict, List, Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CompletionGenerationChoiceLogprobs:
    text_offset: Optional[List[int]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('textOffset'), 'exclude': lambda f: f is None }})
    token_logprobs: Optional[List[float]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tokenLogprobs'), 'exclude': lambda f: f is None }})
    tokens: Optional[List[str]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tokens'), 'exclude': lambda f: f is None }})
    top_logprobs: Optional[List[Dict[str, str]]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('topLogprobs'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional
from writer import utils

class TermExampleType(str, Enum):
    GOOD = 'good'
    BAD = 'bad'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class TermExample:
    example: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('example') }})
    term_bank_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('termBankId') }})
    term_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('termId') }})
    type: TermExampleType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    id: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses


@dataclasses.dataclass
class File:
    content: bytes = dataclasses.field(metadata={'multipart_form': { 'content': True }})
    file_name: str = dataclasses.field(metadata={'multipart_form': { 'field_name': 'file' }})
    



@dataclasses.dataclass
class UploadModelFileRequest:
    file: File = dataclasses.field(metadata={'multipart_form': { 'file': True }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from .paginatedresult_snippetwithuser import PaginatedResultSnippetWithUser
from enum import Enum
from typing import Dict, List, Optional

class SortField(str, Enum):
    SHORTCUT = 'shortcut'
    CREATION_TIME = 'creationTime'
    MODIFICATION_TIME = 'modificationTime'

class SortOrder(str, Enum):
    ASC = 'asc'
    DESC = 'desc'


@dataclasses.dataclass
class FindSnippetsRequest:
    team_id: int = dataclasses.field(metadata={'path_param': { 'field_name': 'teamId', 'style': 'simple', 'explode': False }})
    limit: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'limit', 'style': 'form', 'explode': True }})
    offset: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'offset', 'style': 'form', 'explode': True }})
    organization_id: Optional[int] = dataclasses.field(default=None, metadata={'path_param': { 'field_name': 'organizationId', 'style': 'simple', 'explode': False }})
    search: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'search', 'style': 'form', 'explode': True }})
    shortcuts: Optional[List[str]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'shortcuts', 'style': 'form', 'explode': True }})
    sort_field: Optional[SortField] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sortField', 'style': 'form', 'explode': True }})
    sort_order: Optional[SortOrder] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sortOrder', 'style': 'form', 'explode': True }})
    tags: Optional[List[str]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'tags', 'style': 'form', 'explode': True }})
    



@dataclasses.dataclass
class FindSnippetsResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    headers: Dict[str, List[str]] = dataclasses.field()
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    paginated_result_snippet_with_user: Optional[PaginatedResultSnippetWithUser] = dataclasses.field(default=None)
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .addtermsop import *
from .approvedtermextension import *
from .approvedtermextensioncreate import *
from .briefdocument import *
from .briefdocuments import *
from .completiongenerationchoice import *
from .completiongenerationchoicelogprobs import *
from .completionrequest import *
from .completionresponse import *
from .contentcheckop import *
from .contentcorrectop import *
from .contentdetectorrequest import *
from .contentdetectorresponse import *
from .contentissue import *
from .contentrequest import *
from .contentsettings import *
from .correctionresponse import *
from .createcompletionop import *
from .createcustomizationrequest import *
from .createmodelcustomizationcompletionop import *
from .createmodelcustomizationop import *
from .createtermsrequest import *
from .createtermsresponse import *
from .customizationsresponse import *
from .deletefileop import *
from .deletemodelcustomizationop import *
from .deleteresponse import *
from .deletesnippetsop import *
from .deletetermsop import *
from .detectcontentop import *
from .document import *
from .draft import *
from .failmessage import *
from .failresponse import *
from .fetchcustomizedmodelfileop import *
from .findsnippetsop import *
from .findtermsop import *
from .fulllinkedterm import *
from .fulltermwithuser import *
from .generate_contentop import *
from .generatetemplaterequest import *
from .generationmodelinforesponse import *
from .generationmodelsresponse import *
from .getdocumentdetailsop import *
from .getfileop import *
from .getmodelcustomizationop import *
from .getsubscriptiondetailsop import *
from .hyperparameters import *
from .input import *
from .linkedtermcreate import *
from .listfilesop import *
from .listmodelcustomizationsop import *
from .listmodelsop import *
from .listpagesop import *
from .listteamdocumentsop import *
from .listtemplatesop import *
from .listusersop import *
from .magicrequestinput import *
from .metadata import *
from .modelcustomization import *
from .modelfile import *
from .modelfilesresponse import *
from .pagedetailsop import *
from .pagepublicapiresponse import *
from .pagewithsectionresponse import *
from .paginatedresult_fulltermwithuser import *
from .paginatedresult_pagepublicapiresponse import *
from .paginatedresult_snippetwithuser import *
from .paginatedresult_userpublicresponse import *
from .pagination import *
from .processedcontent import *
from .sdkerror import *
from .sectioninfo import *
from .security import *
from .simpleuser import *
from .snippettagv2 import *
from .snippetupdate import *
from .snippetwithuser import *
from .subscriptionpublicresponseapi import *
from .templatedetailsresponse import *
from .termcreate import *
from .termexample import *
from .termexamplecreate import *
from .terminologyuser import *
from .termmistake import *
from .termmistakecreate import *
from .termtagcreate import *
from .termtagresponse import *
from .termupdate import *
from .updatesnippetsop import *
from .updatetermsop import *
from .updatetermsrequest import *
from .uploadfileop import *
from .uploadmodelfilerequest import *
from .usage import *
from .usageitem import *
from .userpublicresponse import *

__all__ = ["Access","AccountStatus","AddTermsRequest","AddTermsResponse","ApprovedTermExtension","ApprovedTermExtensionCreate","BriefDocument","BriefDocuments","CompletionGenerationChoice","CompletionGenerationChoiceLogprobs","CompletionRequest","CompletionResponse","ContentCheckRequest","ContentCheckResponse","ContentCorrectRequest","ContentCorrectResponse","ContentDetectorRequest","ContentDetectorResponse","ContentIssue","ContentRequest","ContentSettings","CorrectionResponse","CreateCompletionRequest","CreateCompletionResponse","CreateCustomizationRequest","CreateModelCustomizationCompletionRequest","CreateModelCustomizationCompletionResponse","CreateModelCustomizationRequest","CreateModelCustomizationResponse","CreateTermsRequest","CreateTermsResponse","CustomizationsResponse","DeleteFileRequest","DeleteFileResponse","DeleteFileResponseBody","DeleteModelCustomizationRequest","DeleteModelCustomizationResponse","DeleteModelCustomizationResponseBody","DeleteResponse","DeleteSnippetsRequest","DeleteSnippetsResponse","DeleteTermsRequest","DeleteTermsResponse","DetectContentRequest","DetectContentResponse","Document","DocumentAccess","Draft","FailHandling","FailMessage","FailResponse","FetchCustomizedModelFileRequest","FetchCustomizedModelFileResponse","File","FindSnippetsRequest","FindSnippetsResponse","FindTermsRequest","FindTermsResponse","FullLinkedTerm","FullTermWithUser","FullTermWithUserPos","GenerateContentRequest","GenerateContentResponse","GenerateTemplateRequest","GenerationModelInfoResponse","GenerationModelInfoResponseType","GenerationModelsResponse","GetDocumentDetailsRequest","GetDocumentDetailsResponse","GetFileRequest","GetFileResponse","GetModelCustomizationRequest","GetModelCustomizationResponse","GetSubscriptionDetailsResponse","HyperParameters","Input","InputType","Label","LinkedTermCreate","ListFilesRequest","ListFilesResponse","ListModelCustomizationsRequest","ListModelCustomizationsResponse","ListModelsRequest","ListModelsResponse","ListPagesRequest","ListPagesResponse","ListTeamDocumentsQueryParamSortField","ListTeamDocumentsQueryParamSortOrder","ListTeamDocumentsRequest","ListTeamDocumentsResponse","ListTemplatesRequest","ListTemplatesResponse","ListUsersQueryParamSortField","ListUsersQueryParamSortOrder","ListUsersRequest","ListUsersResponse","MagicRequestInput","MetaData","ModelCustomization","ModelFile","ModelFilesResponse","PageDetailsRequest","PageDetailsResponse","PagePublicAPIResponse","PageWithSectionResponse","PageWithSectionResponseStatus","PaginatedResultFullTermWithUser","PaginatedResultPagePublicAPIResponse","PaginatedResultSnippetWithUser","PaginatedResultUserPublicResponse","Pagination","PartOfSpeech","Pos","ProcessedContent","ProductName","QueryParamSortField","QueryParamSortOrder","QueryParamStatus","QueryParamType","SDKError","SectionInfo","Security","Service","SimpleUser","SnippetTagV2","SnippetUpdate","SnippetWithUser","SortField","SortOrder","Status","SubscriptionPublicResponseAPI","SubscriptionPublicResponseAPIStatus","TemplateDetailsResponse","TermCreate","TermCreatePos","TermCreateType","TermExample","TermExampleCreate","TermExampleCreateType","TermExampleType","TermMistake","TermMistakeCreate","TermMistakeCreatePos","TermMistakePos","TermTagCreate","TermTagResponse","TermUpdate","TermUpdatePos","TermUpdateType","TerminologyUser","Tier","Type","UpdateSnippetsRequest","UpdateSnippetsResponse","UpdateTermsRequest","UpdateTermsRequest1","UpdateTermsRequestFailHandling","UpdateTermsResponse","UploadFileRequest","UploadFileResponse","UploadModelFileRequest","Usage","UsageItem","UserPublicResponse"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .sdkconfiguration import SDKConfiguration
from typing import List, Optional
from writer import models, utils

class Snippet:
    r"""Methods related to Snippets"""
    sdk_configuration: SDKConfiguration

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        self.sdk_configuration = sdk_config
        
    
    
    def delete(self, team_id: int, x_request_id: Optional[str] = None, ids: Optional[List[str]] = None, organization_id: Optional[int] = None) -> models.DeleteSnippetsResponse:
        r"""Delete snippets"""
        request = models.DeleteSnippetsRequest(
            team_id=team_id,
            x_request_id=x_request_id,
            ids=ids,
            organization_id=organization_id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(models.DeleteSnippetsRequest, base_url, '/snippet/organization/{organizationId}/team/{teamId}', request, self.sdk_configuration.globals)
        headers = utils.get_headers(request)
        query_params = utils.get_query_params(models.DeleteSnippetsRequest, request, self.sdk_configuration.globals)
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        if callable(self.sdk_configuration.security):
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security())
        else:
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security)
        
        http_res = client.request('DELETE', url, params=query_params, headers=headers)
        content_type = http_res.headers.get('Content-Type')
        
        res = models.DeleteSnippetsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res, headers=None)
        
        if http_res.status_code == 200:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[models.DeleteResponse])
                res.delete_response = out
            else:
                raise models.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, models.FailResponse)
                out.raw_response = http_res
                raise out
            else:
                raise models.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code >= 400 and http_res.status_code < 500 or http_res.status_code >= 500 and http_res.status_code < 600:
            raise models.SDKError('API error occurred', http_res.status_code, http_res.text, http_res)

        return res

    
    
    def find(self, request: models.FindSnippetsRequest) -> models.FindSnippetsResponse:
        r"""Find snippets"""
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(models.FindSnippetsRequest, base_url, '/snippet/organization/{organizationId}/team/{teamId}', request, self.sdk_configuration.globals)
        headers = {}
        query_params = utils.get_query_params(models.FindSnippetsRequest, request, self.sdk_configuration.globals)
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        if callable(self.sdk_configuration.security):
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security())
        else:
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security)
        
        http_res = client.request('GET', url, params=query_params, headers=headers)
        content_type = http_res.headers.get('Content-Type')
        
        res = models.FindSnippetsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res, headers=None)
        
        if http_res.status_code == 200:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[models.PaginatedResultSnippetWithUser])
                res.paginated_result_snippet_with_user = out
            else:
                raise models.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, models.FailResponse)
                out.raw_response = http_res
                raise out
            else:
                raise models.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code >= 400 and http_res.status_code < 500 or http_res.status_code >= 500 and http_res.status_code < 600:
            raise models.SDKError('API error occurred', http_res.status_code, http_res.text, http_res)

        return res

    
    
    def update(self, team_id: int, request_body: Optional[List[models.SnippetUpdate]] = None, x_request_id: Optional[str] = None, organization_id: Optional[int] = None) -> models.UpdateSnippetsResponse:
        r"""Update snippets"""
        request = models.UpdateSnippetsRequest(
            team_id=team_id,
            request_body=request_body,
            x_request_id=x_request_id,
            organization_id=organization_id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(models.UpdateSnippetsRequest, base_url, '/snippet/organization/{organizationId}/team/{teamId}', request, self.sdk_configuration.globals)
        headers = utils.get_headers(request)
        req_content_type, data, form = utils.serialize_request_body(request, models.UpdateSnippetsRequest, "request_body", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        if callable(self.sdk_configuration.security):
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security())
        else:
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security)
        
        http_res = client.request('PUT', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')
        
        res = models.UpdateSnippetsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res, headers=None)
        
        if http_res.status_code == 200:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[List[models.SnippetWithUser]])
                res.classes = out
            else:
                raise models.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, models.FailResponse)
                out.raw_response = http_res
                raise out
            else:
                raise models.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code >= 400 and http_res.status_code < 500 or http_res.status_code >= 500 and http_res.status_code < 600:
            raise models.SDKError('API error occurred', http_res.status_code, http_res.text, http_res)

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from .paginatedresult_fulltermwithuser import PaginatedResultFullTermWithUser
from enum import Enum
from typing import Dict, List, Optional

class PartOfSpeech(str, Enum):
    NOUN = 'noun'
    VERB = 'verb'
    ADVERB = 'adverb'
    ADJECTIVE = 'adjective'

class QueryParamSortField(str, Enum):
    TERM = 'term'
    CREATION_TIME = 'creationTime'
    MODIFICATION_TIME = 'modificationTime'
    TYPE = 'type'

class QueryParamSortOrder(str, Enum):
    ASC = 'asc'
    DESC = 'desc'

class QueryParamType(str, Enum):
    APPROVED = 'approved'
    BANNED = 'banned'
    PENDING = 'pending'


@dataclasses.dataclass
class FindTermsRequest:
    team_id: int = dataclasses.field(metadata={'path_param': { 'field_name': 'teamId', 'style': 'simple', 'explode': False }})
    limit: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'limit', 'style': 'form', 'explode': True }})
    offset: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'offset', 'style': 'form', 'explode': True }})
    organization_id: Optional[int] = dataclasses.field(default=None, metadata={'path_param': { 'field_name': 'organizationId', 'style': 'simple', 'explode': False }})
    part_of_speech: Optional[PartOfSpeech] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'partOfSpeech', 'style': 'form', 'explode': True }})
    sort_field: Optional[QueryParamSortField] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sortField', 'style': 'form', 'explode': True }})
    sort_order: Optional[QueryParamSortOrder] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sortOrder', 'style': 'form', 'explode': True }})
    tags: Optional[List[str]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'tags', 'style': 'form', 'explode': True }})
    term: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'term', 'style': 'form', 'explode': True }})
    type: Optional[QueryParamType] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'type', 'style': 'form', 'explode': True }})
    



@dataclasses.dataclass
class FindTermsResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    headers: Dict[str, List[str]] = dataclasses.field()
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    paginated_result_full_term_with_user: Optional[PaginatedResultFullTermWithUser] = dataclasses.field(default=None)
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from typing import Optional
from writer import utils

class AccountStatus(str, Enum):
    INVITED = 'invited'
    SIGNED_UP = 'signed_up'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UserPublicResponse:
    account_status: AccountStatus = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('accountStatus') }})
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse }})
    first_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('firstName') }})
    full_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('fullName') }})
    id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    avatar: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('avatar'), 'exclude': lambda f: f is None }})
    email: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email'), 'exclude': lambda f: f is None }})
    invited_by: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('invitedBy'), 'exclude': lambda f: f is None }})
    last_name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('lastName'), 'exclude': lambda f: f is None }})
    last_seen_online: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('lastSeenOnline'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'exclude': lambda f: f is None }})
    timezone: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('timezone'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from typing import Any, Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Draft:
    body: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('body') }})
    created_user_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdUserId') }})
    creation_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('creationTime'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse }})
    deleted: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('deleted') }})
    document_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('documentId') }})
    inputs: Any = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('inputs') }})
    organization_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organizationId') }})
    team_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('teamId') }})
    template_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('templateId') }})
    id: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
    title: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from .approvedtermextension import ApprovedTermExtension
from .fulllinkedterm import FullLinkedTerm
from .termexample import TermExample
from .terminologyuser import TerminologyUser
from .termmistake import TermMistake
from .termtagresponse import TermTagResponse
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from typing import List, Optional
from writer import utils

class FullTermWithUserPos(str, Enum):
    NOUN = 'noun'
    VERB = 'verb'
    ADVERB = 'adverb'
    ADJECTIVE = 'adjective'

class Type(str, Enum):
    APPROVED = 'approved'
    BANNED = 'banned'
    PENDING = 'pending'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class FullTermWithUser:
    case_sensitive: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('caseSensitive') }})
    created_user: TerminologyUser = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdUser') }})
    creation_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('creationTime'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse }})
    highlight: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('highlight') }})
    id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    modification_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('modificationTime'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse }})
    modified_user: TerminologyUser = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('modifiedUser') }})
    term: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('term') }})
    term_bank_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('termBankId') }})
    type: Type = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    approved_term_extension: Optional[ApprovedTermExtension] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('approvedTermExtension'), 'exclude': lambda f: f is None }})
    backlinked_terms: Optional[List[FullLinkedTerm]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('backlinkedTerms'), 'exclude': lambda f: f is None }})
    description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
    examples: Optional[List[TermExample]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('examples'), 'exclude': lambda f: f is None }})
    linked_terms: Optional[List[FullLinkedTerm]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('linkedTerms'), 'exclude': lambda f: f is None }})
    mistakes: Optional[List[TermMistake]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('mistakes'), 'exclude': lambda f: f is None }})
    pos: Optional[FullTermWithUserPos] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pos'), 'exclude': lambda f: f is None }})
    tags: Optional[List[TermTagResponse]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tags'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .snippettagv2 import SnippetTagV2
from dataclasses_json import Undefined, dataclass_json
from typing import List, Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class SnippetUpdate:
    id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    snippet: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('snippet') }})
    description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
    shortcut: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('shortcut'), 'exclude': lambda f: f is None }})
    tags: Optional[List[SnippetTagV2]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tags'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from .ai_content_detector import AIContentDetector
from .billing import Billing
from .completions import Completions
from .content import Content
from .cowrite import CoWrite
from .document_sdk import DocumentSDK
from .download_the_customized_model import DownloadTheCustomizedModel
from .files import Files
from .modelcustomization_sdk import ModelCustomizationSDK
from .models_ import Models
from .sdkconfiguration import SDKConfiguration
from .snippet import Snippet
from .styleguide import Styleguide
from .terminology import Terminology
from .user import User
from typing import Callable, Dict, Union
from writer import models, utils

class Writer:
    billing: Billing
    r"""Methods related to Billing"""
    ai_content_detector: AIContentDetector
    r"""Methods related to AI Content Detector"""
    content: Content
    r"""Methods related to Content"""
    co_write: CoWrite
    r"""Methods related to CoWrite"""
    files: Files
    r"""Methods related to Files"""
    models: Models
    r"""Methods related to Model"""
    completions: Completions
    r"""Methods related to Completions"""
    model_customization: ModelCustomizationSDK
    r"""Methods related to Model Customization"""
    download_the_customized_model: DownloadTheCustomizedModel
    r"""Methods related to Download the customized model"""
    document: DocumentSDK
    r"""Methods related to document"""
    snippet: Snippet
    r"""Methods related to Snippets"""
    styleguide: Styleguide
    r"""Methods related to Styleguide"""
    terminology: Terminology
    r"""Methods related to Terminology"""
    user: User
    r"""Methods related to User"""

    sdk_configuration: SDKConfiguration

    def __init__(self,
                 api_key: Union[str, Callable[[], str]],
                 organization_id: int = None,
                 server_idx: int = None,
                 server_url: str = None,
                 url_params: Dict[str, str] = None,
                 client: requests_http.Session = None,
                 retry_config: utils.RetryConfig = None
                 ) -> None:
        """Instantiates the SDK configuring it with the provided parameters.
        
        :param api_key: The api_key required for authentication
        :type api_key: Union[str, Callable[[], str]]
        :param organization_id: Configures the organization_id parameter for all supported operations
        :type organization_id: int
        :param server_idx: The index of the server to use for all operations
        :type server_idx: int
        :param server_url: The server URL to use for all operations
        :type server_url: str
        :param url_params: Parameters to optionally template the server URL with
        :type url_params: Dict[str, str]
        :param client: The requests.Session HTTP client to use for all operations
        :type client: requests_http.Session
        :param retry_config: The utils.RetryConfig to use globally
        :type retry_config: utils.RetryConfig
        """
        if client is None:
            client = requests_http.Session()
        
        if callable(api_key):
            def security():
                return models.Security(api_key = api_key())
        else:
            security = models.Security(api_key = api_key)
        
        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        self.sdk_configuration = SDKConfiguration(client, security, server_url, server_idx, {
            'parameters': {
                'queryParam': {
                },
                'pathParam': {
                    'organization_id': organization_id,
                },
            },
        }, retry_config=retry_config)
       
        self._init_sdks()
    
    def _init_sdks(self):
        self.billing = Billing(self.sdk_configuration)
        self.ai_content_detector = AIContentDetector(self.sdk_configuration)
        self.content = Content(self.sdk_configuration)
        self.co_write = CoWrite(self.sdk_configuration)
        self.files = Files(self.sdk_configuration)
        self.models = Models(self.sdk_configuration)
        self.completions = Completions(self.sdk_configuration)
        self.model_customization = ModelCustomizationSDK(self.sdk_configuration)
        self.download_the_customized_model = DownloadTheCustomizedModel(self.sdk_configuration)
        self.document = DocumentSDK(self.sdk_configuration)
        self.snippet = Snippet(self.sdk_configuration)
        self.styleguide = Styleguide(self.sdk_configuration)
        self.terminology = Terminology(self.sdk_configuration)
        self.user = User(self.sdk_configuration)
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .modelcustomization import ModelCustomization
from dataclasses_json import Undefined, dataclass_json
from typing import List, Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CustomizationsResponse:
    customizations: Optional[List[ModelCustomization]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('customizations'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ModelFile:
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse }})
    format: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('format') }})
    id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    number_of_samples: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('numberOfSamples') }})
    size: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('size') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .usageitem import UsageItem
from dataclasses_json import Undefined, dataclass_json
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Usage:
    co_write_words: UsageItem = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('coWriteWords') }})
    team: UsageItem = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('team') }})
    user: UsageItem = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user') }})
    words: UsageItem = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('words') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .hyperparameters import HyperParameters
from dataclasses_json import Undefined, dataclass_json
from typing import Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateCustomizationRequest:
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    training_dataset_file_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('trainingDatasetFileId') }})
    additional_hyper_parameters: Optional[HyperParameters] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('additionalHyperParameters'), 'exclude': lambda f: f is None }})
    batch_size: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('batchSize'), 'exclude': lambda f: f is None }})
    description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
    epochs: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('epochs'), 'exclude': lambda f: f is None }})
    learning_rate: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('learningRate'), 'exclude': lambda f: f is None }})
    prompt_template: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('promptTemplate'), 'exclude': lambda f: f is None }})
    validation_dataset_file_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('validationDatasetFileId'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from writer import utils

class TermExampleCreateType(str, Enum):
    GOOD = 'good'
    BAD = 'bad'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class TermExampleCreate:
    example: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('example') }})
    type: TermExampleCreateType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from .paginatedresult_pagepublicapiresponse import PaginatedResultPagePublicAPIResponse
from enum import Enum
from typing import Dict, List, Optional

class QueryParamStatus(str, Enum):
    LIVE = 'live'
    OFFLINE = 'offline'


@dataclasses.dataclass
class ListPagesRequest:
    limit: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'limit', 'style': 'form', 'explode': True }})
    offset: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'offset', 'style': 'form', 'explode': True }})
    status: Optional[QueryParamStatus] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'status', 'style': 'form', 'explode': True }})
    



@dataclasses.dataclass
class ListPagesResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    headers: Dict[str, List[str]] = dataclasses.field()
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    paginated_result_page_public_api_response: Optional[PaginatedResultPagePublicAPIResponse] = dataclasses.field(default=None)
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests
from dataclasses import dataclass, field
from typing import Any, Dict, Tuple, Callable, Union
from .utils.retries import RetryConfig
from .utils import utils
from writer import models


SERVERS = [
    'https://enterprise-api.writer.com',
]
"""Contains the list of servers available to the SDK"""

@dataclass
class SDKConfiguration:
    client: requests.Session
    security: Union[models.Security,Callable[[], models.Security]] = None
    server_url: str = ''
    server_idx: int = 0
    globals: Dict[str, Dict[str, Dict[str, Any]]] = field(default_factory=Dict)
    language: str = 'python'
    openapi_doc_version: str = '1.7'
    sdk_version: str = '1.2.4'
    gen_version: str = '2.237.2'
    user_agent: str = 'speakeasy-sdk/python 1.2.4 2.237.2 1.7 writerai'
    retry_config: RetryConfig = None

    def get_server_details(self) -> Tuple[str, Dict[str, str]]:
        if self.server_url:
            return utils.remove_suffix(self.server_url, '/'), {}
        if self.server_idx is None:
            self.server_idx = 0

        return SERVERS[self.server_idx], {}



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from typing import Dict, List, Optional


@dataclasses.dataclass
class FetchCustomizedModelFileRequest:
    customization_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'customizationId', 'style': 'simple', 'explode': False }})
    model_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'modelId', 'style': 'simple', 'explode': False }})
    organization_id: Optional[int] = dataclasses.field(default=None, metadata={'path_param': { 'field_name': 'organizationId', 'style': 'simple', 'explode': False }})
    



@dataclasses.dataclass
class FetchCustomizedModelFileResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    headers: Dict[str, List[str]] = dataclasses.field()
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    stream: Optional[requests_http.Response] = dataclasses.field(default=None)
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .approvedtermextension import ApprovedTermExtension
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional
from writer import utils

class Pos(str, Enum):
    NOUN = 'noun'
    VERB = 'verb'
    ADVERB = 'adverb'
    ADJECTIVE = 'adjective'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class FullLinkedTerm:
    case_sensitive: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('caseSensitive') }})
    linked_term_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('linkedTermId') }})
    term: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('term') }})
    term_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('termId') }})
    approved_term_extension: Optional[ApprovedTermExtension] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('approvedTermExtension'), 'exclude': lambda f: f is None }})
    id: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
    pos: Optional[Pos] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pos'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from .sectioninfo import SectionInfo
from .simpleuser import SimpleUser
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from typing import Optional
from writer import utils

class Status(str, Enum):
    LIVE = 'live'
    OFFLINE = 'offline'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PagePublicAPIResponse:
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse }})
    id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    order: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('order') }})
    status: Status = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updatedAt'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse }})
    url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('url') }})
    section: Optional[SectionInfo] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('section'), 'exclude': lambda f: f is None }})
    updated_by: Optional[SimpleUser] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updatedBy'), 'exclude': lambda f: f is None }})
    

